==> haskell-ormolu-0.6.0.0-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ormolu
version:              0.6.0.0
visibility:           public
id:                   ormolu-0.6.0.0-4FP0SmtlYEjKz5nBmJkNQ8
key:                  ormolu-0.6.0.0-4FP0SmtlYEjKz5nBmJkNQ8
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  2a221a0bae5cfde78f2afca7e442f8cd
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal
    Ormolu.Terminal.QualifiedDo Ormolu.Utils Ormolu.Utils.Cabal
    Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ormolu-0.6.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ormolu-0.6.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ormolu-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.6.0.0-4FP0SmtlYEjKz5nBmJkNQ8
depends:
    Cabal-syntax-3.10.3.0 Diff-0.5-yETzKh0qtuDUuvJdOns8X
    MemoTrie-0.6.11-EzCPS0AcENCFqJcGrA4JYn
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt array-0.5.6.0
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9 mtl-2.3.1
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ormolu-0.6.0.0-5-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ormolu
version:              0.6.0.0
visibility:           public
id:                   ormolu-0.6.0.0-5EXHXBmD8HN9DSAYOg9vhr
key:                  ormolu-0.6.0.0-5EXHXBmD8HN9DSAYOg9vhr
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  4114776b9ac198f21ea7f2caf117cfa3
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal
    Ormolu.Terminal.QualifiedDo Ormolu.Utils Ormolu.Utils.Cabal
    Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ormolu-0.6.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ormolu-0.6.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ormolu-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.6.0.0-5EXHXBmD8HN9DSAYOg9vhr
depends:
    Cabal-syntax-3.10.3.0 Diff-0.5-8gj4s2z6jOl7FPRCGftIez
    MemoTrie-0.6.11-JBrVOshtmKn292FiNTA9B
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh array-0.5.6.0
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE mtl-2.3.1
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
